@@ -3,8 +3,8 @@ import time
 import sys
 import signal
 
-from modpoll import __version__
-from modpoll.args import args
+# from modpoll import __version__
+from modpoll.arg_parser import get_parser
 from modpoll.mqtt_task import mqttc_setup, mqttc_publish, mqttc_close
 from modpoll.modbus_task import modbus_setup, modbus_poll, modbus_export, modbus_close
 
@@ -16,23 +16,30 @@ LOG_SIMPLE = "%(asctime)s | %(levelname).1s | %(name)s | %(message)s"
 LOG_PROCESS = "%(asctime)s | %(levelname).1s | %(processName)s | %(name)s | %(message)s"
 LOG_THREAD = "%(asctime)s | %(levelname).1s | %(threadName)s | %(name)s | %(message)s"
 logging.basicConfig(
-    level=args.loglevel.upper(),
+    level="INFO",
     format=LOG_SIMPLE,
 )
-# get logger
-log = logging.getLogger(__name__)
-
 
 def _signal_handler(signal, frame):
-    log.info(f"Exiting {sys.argv[0]}")
     print('Exiting ' + sys.argv[0])
     _shutdown()
 
 
 def app(name="modpoll"):
-    log.info(f"Starting {name} v{__version__}")
+    # log.info(f"Starting {name} v{__version__}")
     signal.signal(signal.SIGINT, _signal_handler)
 
+    # get logger
+    log = logging.getLogger(__name__)
+
+    # check args
+    args = get_parser().parse_args()
+    if not args.config:
+        log.error("Modbus configuration file is missing. Required!")
+        exit(1)
+    
+    log.setLevel(args.loglevel)
+
     # setup mqtt
     if args.mqtt_host:
         log.info(f"Setup MQTT connection to {args.mqtt_host}")
@@ -44,7 +51,7 @@ def app(name="modpoll"):
         log.info("No MQTT host specified, skip MQTT setup.")
 
     # setup modbus
-    if not modbus_setup():
+    if not modbus_setup(args):
         log.error("fail to setup modbus client(master)")
         modbus_close()
         mqttc_close()
