@@ -10,9 +10,7 @@ log = logging.getLogger(__name__)
 
 # global objects
 _mqttc = None
-_qos = 0
-initial_connection_made = False
-subscribe_topic = "ysdtest/#"
+_initial_connection_made = False
 
 
 # Callbacks
@@ -21,7 +19,7 @@ def _on_connect(client, userdata, flags, rc, properties=None):
         log.info("Connection successful")
         # Subscribing in on_connect() means that if we lose the connection and
         # reconnect then subscriptions will be renewed.
-        client.subscribe(subscribe_topic)
+        # client.subscribe(subscribe_topic)
     elif rc == 1:
         log.warning("Connection refused - incorrect protocol version")
     elif rc == 2:
@@ -65,9 +63,8 @@ def mqttc_setup(host: str, port=1883, user=None, password="", qos=0, mqtt_debug=
         # mqttc = mqtt.Client("client-id")
         # but note that the client id must be unique on the broker. Leaving the client
         # id parameter empty will generate a random id for you.
-        global _mqttc, _qos, initial_connection_made
-        _qos = qos
-        _mqttc = mqtt.Client(str(uuid.uuid4()), clean_session=(_qos == 0))
+        global _mqttc, _initial_connection_made
+        _mqttc = mqtt.Client(str(uuid.uuid4()), clean_session=(qos == 0))
         # if args.mqtt_use_tls:
         #     if args.mqtt_tls_version == "tlsv1.2":
         #         tlsVersion = ssl.PROTOCOL_TLSv1_2
@@ -110,7 +107,7 @@ def mqttc_setup(host: str, port=1883, user=None, password="", qos=0, mqtt_debug=
         # start loop - let paho manage connection
         _mqttc.loop_start()
 
-        initial_connection_made = True
+        _initial_connection_made = True
         return True
 
     except Exception as ex:
